@@ -13,10 +13,9 @@
 
 """Base API Library"""
 
-import simplejson as json
-
 from keystoneauth1 import exceptions as ksa_exceptions
 from keystoneauth1 import session as ksa_session
+import simplejson as json
 
 from osc_lib import exceptions
 from osc_lib.i18n import _
@@ -27,10 +26,13 @@ class BaseAPI(object):
 
     Encapsulate the translation between keystoneauth1.session.Session
     and requests.Session in a single layer:
+
     * Restore some requests.session.Session compatibility;
       keystoneauth1.session.Session.request() has the method and url
       arguments swapped from the rest of the requests-using world.
-    * Provide basic endpoint handling when a Service Catalog is not available.
+    * Provide basic endpoint handling when a Service Catalog is not
+      available.
+
     """
 
     # Which service are we? Set in API-specific subclasses
@@ -69,7 +71,28 @@ class BaseAPI(object):
             self.session = session
 
         self.service_type = service_type
-        self.endpoint = endpoint
+        self.endpoint = self._munge_endpoint(endpoint)
+
+    def _munge_endpoint(self, endpoint):
+        """Hook to allow subclasses to massage the passed-in endpoint
+
+        Hook to massage passed-in endpoints from arbitrary sources,
+        including direct user input.  By default just remove trailing
+        '/' as all of our path info strings start with '/' and not all
+        services can handle '//' in their URLs.
+
+        Some subclasses will override this to do additional work, most
+        likely with regard to API versions.
+
+        :param string endpoint: The service endpoint, generally direct
+                                from the service catalog.
+        :return: The modified endpoint
+        """
+
+        if isinstance(endpoint, str):
+            return endpoint.rstrip('/')
+        else:
+            return endpoint
 
     def _request(self, method, url, session=None, **kwargs):
         """Perform call into session
@@ -99,6 +122,9 @@ class BaseAPI(object):
             if url:
                 url = '/'.join([self.endpoint.rstrip('/'), url.lstrip('/')])
             else:
+                # NOTE(dtroyer): This is left here after _munge_endpoint() is
+                #                added because endpoint is public and there is
+                #                no accounting for what may happen.
                 url = self.endpoint.rstrip('/')
         else:
             # Pass on the lack of URL unmolested to maintain the same error
@@ -300,7 +326,6 @@ class BaseAPI(object):
         :returns: list of resource dicts
         """
 
-        print("keys: %s" % kwargs.keys())
         items = self.list(path)
         if isinstance(items, dict):
             # strip off the enclosing dict
@@ -334,7 +359,7 @@ class BaseAPI(object):
         num_bulk = len(bulk_list)
         if num_bulk == 0:
             msg = _("none found")
-            raise exceptions.NotFound(msg)
+            raise exceptions.NotFound(404, msg)
         elif num_bulk > 1:
             msg = _("many found")
             raise RuntimeError(msg)
@@ -359,6 +384,10 @@ class BaseAPI(object):
             Headers dictionary to pass to requests
         """
 
+        def raise_not_found():
+            msg = _("%s not found") % value
+            raise exceptions.NotFound(404, msg)
+
         try:
             ret = self._request(
                 'GET', "/%s/%s" % (path, value),
@@ -372,18 +401,20 @@ class BaseAPI(object):
             ksa_exceptions.NotFound,
             ksa_exceptions.BadRequest,
         ):
-            kwargs = {attr: value}
-            try:
-                ret = self.find_one(
-                    path,
-                    headers=headers,
-                    **kwargs
-                )
-            except (
-                exceptions.NotFound,
-                ksa_exceptions.NotFound,
-            ):
-                msg = _("%s not found") % value
-                raise exceptions.NotFound(msg)
+            if attr:
+                kwargs = {attr: value}
+                try:
+                    ret = self.find_one(
+                        path,
+                        headers=headers,
+                        **kwargs
+                    )
+                except (
+                    exceptions.NotFound,
+                    ksa_exceptions.NotFound,
+                ):
+                    raise_not_found()
+            else:
+                raise_not_found()
 
         return ret
